'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var esCliStyles = require('@open-tech-world/es-cli-styles');

class cliProgress {
    constructor(options) {
        this.stream = (options && options.stream) || process.stderr;
        this.tty = this.stream.isTTY;
        this.isRunning = false;
        this.text = '';
    }
    setText(text) {
        if (!this.isRunning) {
            return;
        }
        if (text) {
            this.text = text + ' ';
        }
    }
    render(text) {
        if (this.tty) {
            if (this.stream.clearLine(0) && this.stream.cursorTo(0)) {
                this.stream.write(text);
            }
            return;
        }
        this.stream.write(text);
    }
    startSpinner() {
        const frames = ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'];
        let currentPosition = 0;
        const intervalInstance = setInterval(() => {
            if (!this.isRunning) {
                clearInterval(intervalInstance);
                return;
            }
            this.render(esCliStyles.style('~green.bold{' + frames[currentPosition] + '} ' + this.text));
            if (currentPosition === frames.length - 1) {
                currentPosition = 0;
                return;
            }
            currentPosition++;
        }, 100);
    }
    start(text) {
        if (this.isRunning) {
            return;
        }
        this.isRunning = true;
        this.setText(text || 'Loading');
        if (this.tty) {
            this.startSpinner();
            return;
        }
        this.render('\u{2B50} Loading\n');
    }
    update(text) {
        this.setText(text);
        if (this.isRunning && !this.tty) {
            this.render('\u{2B50} ' + this.text + '\n');
        }
    }
    done(text) {
        if (!this.isRunning) {
            return;
        }
        this.setText(text);
        this.isRunning = false;
        if (this.tty) {
            this.render(esCliStyles.style('~green.bold{\u{2714}\u{FE0F}}') + '  ' + this.text + '\n');
            return;
        }
        this.render('\u{2714} ' + this.text + '\n');
    }
    fail(text) {
        if (!this.isRunning) {
            return;
        }
        this.setText(text);
        this.isRunning = false;
        if (this.tty) {
            this.render(esCliStyles.style('~red.bold{\u{274C}\u{FE0F}}') + ' ' + this.text + '\n');
            return;
        }
        this.render('\u{274C} ' + this.text + '\n');
    }
    warn(text) {
        if (!this.isRunning) {
            return;
        }
        this.setText(text);
        this.isRunning = false;
        if (this.tty) {
            this.render(esCliStyles.style('~yellow.bold{\u{26A0}\u{FE0F}}') + '  ' + this.text + '\n');
            return;
        }
        this.render('\u{26A0} ' + this.text + '\n');
    }
    info(text) {
        if (!this.isRunning) {
            return;
        }
        this.setText(text);
        this.isRunning = false;
        if (this.tty) {
            this.render(esCliStyles.style('~aqua.bold{\u{2139}\u{FE0F}}') + '  ' + this.text + '\n');
            return;
        }
        this.render('\u{2139} ' + this.text + '\n');
    }
}

exports.cliProgress = cliProgress;
